<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>SRC-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Über Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Qmmp Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SRConverterSettingsDialog</name>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Einstellungen Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Abtastrate (Hz):</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="40"/>
        <source>Interpolation Engine:</source>
        <translation>Interpolation:</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="48"/>
        <source>Best Sinc Interpolation</source>
        <translation>Sinc (hohe Qualität)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="53"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Sinc (mittlere Qualität)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="58"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Schnellste Sinc-Interpolation</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="63"/>
        <source>ZOH Interpolation</source>
        <translation>Zero-Order-Hold (ZOH)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="68"/>
        <source>Linear Interpolation</source>
        <translation>Linear</translation>
    </message>
</context>
</TS>
